==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/vi.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Máy chủ để chia sẻ máy chủ không được kích hoạt trên máy chủ này",
    "The mountpoint name contains invalid characters." : "Tên mountpoint chứa các ký tự không hợp lệ.",
    "Invalid or untrusted SSL certificate" : "Chứng chỉ SSL không hợp lệ hoặc không đáng tin cậy",
    "Shared with you" : "Chia sẻ với bạn",
    "Shared with others" : "Chia sẻ với người khác",
    "Shared by link" : "Chia sẻ theo liên kết",
    "Uploading..." : "tải lên...",
    "Nothing shared with you yet" : "Bạn chưa được chia sẻ gì cả",
    "Nothing shared yet" : "Chưa có gì được chia sẻ",
    "Files and folders you share will show up here" : "Tập tin và thư mục bạn chia sẻ sẽ được hiển thị tại đây.",
    "No shared links" : "Chưa có liên kết chia sẻ",
    "Cancel" : "Hủy",
    "Share" : "Chia sẻ",
    "Shared by" : "Chia sẻ bởi",
    "Sharing" : "Chia sẻ",
    "Shares" : "Chia sẻ",
    "The password is wrong. Try again." : "Mật khẩu sai. Xin hãy thử lại.",
    "Password" : "Mật khẩu",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Name" : "Tên",
    "Share time" : "Chia sẻ thời gian",
    "Expiration date" : "Ngày kết thúc",
    "Reasons might be:" : "Lý do có thể là:",
    "the item was removed" : "đối tượng đã bị xóa",
    "the link expired" : "liên kết đã hết hạn",
    "sharing is disabled" : "việc chia sẻ bị cấm",
    "Add to your ownCloud" : "Thêm vào ownCloud của bạn",
    "Download" : "Tải về",
    "Download %s" : "Tải về %s",
    "Direct link" : "Link trực tiếp"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/vi.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Máy chủ để chia sẻ máy chủ không được kích hoạt trên máy chủ này",
    "The mountpoint name contains invalid characters." : "Tên mountpoint chứa các ký tự không hợp lệ.",
    "Invalid or untrusted SSL certificate" : "Chứng chỉ SSL không hợp lệ hoặc không đáng tin cậy",
    "Shared with you" : "Chia sẻ với bạn",
    "Shared with others" : "Chia sẻ với người khác",
    "Shared by link" : "Chia sẻ theo liên kết",
    "Uploading..." : "tải lên...",
    "Nothing shared with you yet" : "Bạn chưa được chia sẻ gì cả",
    "Nothing shared yet" : "Chưa có gì được chia sẻ",
    "Files and folders you share will show up here" : "Tập tin và thư mục bạn chia sẻ sẽ được hiển thị tại đây.",
    "No shared links" : "Chưa có liên kết chia sẻ",
    "Cancel" : "Hủy",
    "Share" : "Chia sẻ",
    "Shared by" : "Chia sẻ bởi",
    "Sharing" : "Chia sẻ",
    "Shares" : "Chia sẻ",
    "The password is wrong. Try again." : "Mật khẩu sai. Xin hãy thử lại.",
    "Password" : "Mật khẩu",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Name" : "Tên",
    "Share time" : "Chia sẻ thời gian",
    "Expiration date" : "Ngày kết thúc",
    "Reasons might be:" : "Lý do có thể là:",
    "the item was removed" : "đối tượng đã bị xóa",
    "the link expired" : "liên kết đã hết hạn",
    "sharing is disabled" : "việc chia sẻ bị cấm",
    "Add to your ownCloud" : "Thêm vào ownCloud của bạn",
    "Download" : "Tải về",
    "Download %s" : "Tải về %s",
    "Direct link" : "Link trực tiếp",
    "Pending" : "Đang chờ",
    "Accept" : "Đồng ý",
    "Decline" : "Từ chối",
    "Declined" : "Từ chối"
},
"nplurals=1; plural=0;");
